==> apache-hyracks-0.3.3-source-release.zip: apache-hyracks-0.3.3/algebricks/algebricks-core/src/main/java/org/apache/hyracks/algebricks/core/algebra/prettyprint/AlgebricksAppendable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.algebricks.core.algebra.prettyprint;

import java.io.IOException;

import org.apache.hyracks.algebricks.common.exceptions.AlgebricksException;

public class AlgebricksAppendable {
    final Appendable app;

    public AlgebricksAppendable() {
        this.app = new StringBuilder();
    }

    public AlgebricksAppendable(Appendable app) {
        this.app = app;
    }

    public Appendable getAppendable() {
        return app;
    }

    @Override public String toString() {
        return app.toString();
    }

    public AlgebricksAppendable append(CharSequence csq) throws AlgebricksException {
        try {
            app.append(csq);
            return this;
        } catch (IOException e) {
            throw new AlgebricksException(e);
        }
    }

    public AlgebricksAppendable append(CharSequence csq, int start, int end) throws AlgebricksException {
        try {
            app.append(csq, start, end);
            return this;
        } catch (IOException e) {
            throw new AlgebricksException(e);
        }
    }

    public AlgebricksAppendable append(char c) throws AlgebricksException {
        try {
            app.append(c);
            return this;
        } catch (IOException e) {
            throw new AlgebricksException(e);
        }
    }
}

==> apache-hyracks-0.3.9-source-release.zip: apache-hyracks-0.3.9/algebricks/algebricks-core/src/main/java/org/apache/hyracks/algebricks/core/algebra/prettyprint/AlgebricksAppendable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.algebricks.core.algebra.prettyprint;

import java.io.IOException;

import org.apache.hyracks.algebricks.common.exceptions.AlgebricksException;

public class AlgebricksAppendable {
    final Appendable app;

    public AlgebricksAppendable() {
        this.app = new StringBuilder();
    }

    public AlgebricksAppendable(Appendable app) {
        this.app = app;
    }

    public Appendable getAppendable() {
        return app;
    }

    @Override
    public String toString() {
        return app.toString();
    }

    public AlgebricksAppendable append(CharSequence csq) throws AlgebricksException {
        try {
            app.append(csq);
            return this;
        } catch (IOException e) {
            throw new AlgebricksException(e);
        }
    }

    public AlgebricksAppendable append(CharSequence csq, int start, int end) throws AlgebricksException {
        try {
            app.append(csq, start, end);
            return this;
        } catch (IOException e) {
            throw new AlgebricksException(e);
        }
    }

    public AlgebricksAppendable append(char c) throws AlgebricksException {
        try {
            app.append(c);
            return this;
        } catch (IOException e) {
            throw new AlgebricksException(e);
        }
    }
}
